package mysql

import (
	"context"

	"github.com/c9s/rockhopper"
)

func init() {
	AddMigration(upKlineUniqueIdx, downKlineUniqueIdx)

}

func upKlineUniqueIdx(ctx context.Context, tx rockhopper.SQLExecutor) (err error) {
	// This code is executed when the migration is applied.

	_, err = tx.ExecContext(ctx, "TRUNCATE TABLE `binance_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "TRUNCATE TABLE `max_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "TRUNCATE TABLE `ftx_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "TRUNCATE TABLE `kucoin_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "TRUNCATE TABLE `okex_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "CREATE UNIQUE INDEX idx_kline_binance_unique\n    ON binance_klines (`symbol`, `interval`, `start_time`);")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "CREATE UNIQUE INDEX idx_kline_max_unique\n    ON max_klines (`symbol`, `interval`, `start_time`);")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "CREATE UNIQUE INDEX `idx_kline_ftx_unique`\n    ON ftx_klines (`symbol`, `interval`, `start_time`);")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "CREATE UNIQUE INDEX `idx_kline_kucoin_unique`\n    ON kucoin_klines (`symbol`, `interval`, `start_time`);")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "CREATE UNIQUE INDEX `idx_kline_okex_unique`\n    ON okex_klines (`symbol`, `interval`, `start_time`);")
	if err != nil {
		return err
	}

	return err
}

func downKlineUniqueIdx(ctx context.Context, tx rockhopper.SQLExecutor) (err error) {
	// This code is executed when the migration is rolled back.

	_, err = tx.ExecContext(ctx, "DROP INDEX `idx_kline_ftx_unique` ON `ftx_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "DROP INDEX `idx_kline_max_unique` ON `max_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "DROP INDEX `idx_kline_binance_unique` ON `binance_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "DROP INDEX `idx_kline_kucoin_unique` ON `kucoin_klines`;")
	if err != nil {
		return err
	}

	_, err = tx.ExecContext(ctx, "DROP INDEX `idx_kline_okex_unique` ON `okex_klines`;")
	if err != nil {
		return err
	}

	return err
}
